pub enum Role {
Point,
Line,
Plane,
Edge,
Circle,
Round,
Solid,
Sketch,
}Expand description
What a step needs an entity it builds on to be: what a pick looks for, and what a datum construction needs as an input.
Variants
Point
A vertex, a datum point, a frame’s origin, a sketch point.
Line
A straight edge, a datum axis, a frame’s axis, a sketch line.
Plane
A planar face, a datum plane, a frame’s plane.
Edge
Any edge.
Circle
A circular edge.
Round
Something that turns around an axis: a circular edge, a cylindrical, conical or spherical face, a sketch circle.
Solid
A solid, as a whole.
Sketch
A sketch, as a whole.
Implementations