frame_along

Function frame_along 

pub fn frame_along<S: Scalar>(
    origin: Vector3<S>,
    normal: &Vector3<S>,
) -> GeopResult<CoordinateSystem<S>>
A right-handed orthonormal frame at origin with w along normal, and u the world axis most parallel to the plane normal to it, projected into that plane — so frames with parallel normals line up.