pub struct OperationInfo {
pub kind: &'static str,
pub label: &'static str,
pub doc: &'static str,
}Expand description
An operation of a set: how a step spells it, its short name and what it does — what an editor offers it by.
Fields
kind: &'static strlabel: &'static strdoc: &'static strTrait Implementations
Sourceimpl Clone for OperationInfo
impl Clone for OperationInfo
Sourcefn clone(&self) -> OperationInfo
fn clone(&self) -> OperationInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OperationInfo
impl Debug for OperationInfo
Sourceimpl PartialEq for OperationInfo
impl PartialEq for OperationInfo
Sourcefn eq(&self, other: &OperationInfo) -> bool
fn eq(&self, other: &OperationInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for OperationInfo
impl Serialize for OperationInfo
impl StructuralPartialEq for OperationInfo